function [nodes, elements] = create_bridge(nSpan, nFloor)
%create_bridge generate a bridge-like truss model
%  [nodes, elements] = create_bridge(nSpan, nFloor) creates a bridge-like
%  truss model.
%  nodes: Nx2 matrix of nodal locations
%  elements: Ex2 matrix of element nodal indices

nodes = zeros(0,2);
elements = zeros(0,2);

elemstart = 0;
for iFloor = 1 : nFloor + 1
    lSpan = nSpan - iFloor + 1;
    y0 = iFloor - 1;
    x0 = (iFloor-1) / 2;
    nodes = [
        nodes
        x0 + (0 : lSpan)' repmat(y0, lSpan+1, 1)
        ];
    if lSpan > 0
        elements = [
            elements
            elemstart + (1:lSpan)', elemstart + (2:lSpan+1)'
            ];
    end
    
    if iFloor < nFloor + 1
        elements = [
            elements
            elemstart + (1:lSpan)', elemstart + lSpan+1 + (1:lSpan)'
            elemstart + (2:lSpan+1)', elemstart + lSpan+1 + (1:lSpan)'
            ];
    end
    
    elemstart = elemstart + lSpan+1;
end

end % of function
