function [hn, he] = plot_truss(nodes, elements, deformation, color)
%plot_truss display a deformed truss structure
%  [hn, he] = plot_truss(nodes, elements, deformation, color) displays the
%  deformed 2D truss structure
%  nodes: Nx2 matrix of nodal coordinates
%  elements: Ex2 matrix of nodal indices
%  deformation: Nx2 matrix of nodal displacements
%  color: descriptor applied to each element

if nargin < 3
    deformation = zeros(size(nodes,1),2);
    color = 'black';
elseif nargin < 4
    color = 'red';
end

% modify nodal coordinates with deformations
x = nodes(:,1) + deformation(:,1);
y = nodes(:,2) + deformation(:,2);

% plot nodes
hn = plot(x, y, '.', 'Marker', 'd');
% plot elements
he = line(x(elements)', y(elements)', 'color', color);

axis equal

end % of function
